diff --git a/CHANGELOG.md b/CHANGELOG.md
index 476eae31b31336f96874bf2ee399b80830ab0fd0..a4251e1f4c3cf780e40e3de77ffb4792a16b9f8f 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -7,4 +7,4 @@ have been made so far, between releases.
 * removed the requirement for a Queue that for it to be equal to other Queue if their types do match
 * compile_definitions will now depend on requests
 * added support for infinite (None) timeouts during start
-* stress tests will run for 60 seconds now
+* stress tests will run for 120 seconds now
diff --git a/README.md b/README.md
index 60143d8638d9276692fc2fd86f7001855b6cf26f..e69b7c66a470e4434b1604c5dc62a21a240218e8 100644
--- a/README.md
+++ b/README.md
@@ -23,14 +23,14 @@ Why CoolAMQP?
 
 * AMQP 0.9.1 client that's native Python
 * heavily optimized for speed
-* geared towards interfacing with [RabbitMQ](https://www.rabbitmq.com/
+* geared towards interfacing with [RabbitMQ](https://www.rabbitmq.com/)
   * supports custom RabbitMQ commands, such as
     * [Connection blocking](https://www.rabbitmq.com/docs/connection-blocked)
     * [Publisher confirms](https://www.rabbitmq.com/docs/confirms#publisher-confirms)
     * [Negative Acknowledgements](https://www.rabbitmq.com/docs/nack)
 * traceable using [opentracing](https://opentracing.io/)
 * code coverage is 80% at the moment
-* stress tests are part of each release
+* 120 second stress tests are part of each release
 
 Documentation (WIP) is available at [our site](http://smokserwis.docs.smok.co/coolamqp).
 
diff --git a/stress_tests/client.py b/stress_tests/client.py
index f2e6427a3b161bb54cbfb0422dcd27a634cb3aed..d947943f2a1cd6be6ee76bcfb166b6c3d2de1e86 100644
--- a/stress_tests/client.py
+++ b/stress_tests/client.py
@@ -19,7 +19,7 @@ CONNECTIONS_PER_SECOND = 0.9
 DISCONNECTS_PER_SECOND_PER_CONNECTION = 0.1
 ANSWER_PROBABILITY = 0.7
 
-RUNNING_INTERVAL = 60       # run for 60 seconds
+RUNNING_INTERVAL = 120       # run for 120 seconds